import { Buffer } from "buffer"
import type { IAdapter, IFileSystem } from "opvault.js/src/adapter"

export class FileSystem implements IFileSystem {
  private paths = new Set<string>()
  private pathMap = new Map<string, File>()

  constructor(list: FileList) {
    for (const file of list) {
      this.pathMap.set(file.webkitRelativePath, file)
      this.paths.add(file.webkitRelativePath)
    }
  }

  async readFile(path: string) {
    return this.pathMap.get(path)!.text()
  }

  async exists(path: string): Promise<boolean> {
    return this.pathMap.has(path)
  }

  async readBuffer(path: string): Promise<Buffer> {
    const arrayBuffer = await this.pathMap.get(path)!.arrayBuffer()
    return Buffer.from(arrayBuffer)
  }

  // eslint-disable-next-line class-methods-use-this
  async writeFile(path: string, data: string): Promise<void> {
    throw new Error("fs.writeFile is not supported with webkitdirectory")
  }

  async readdir(path: string): Promise<string[]> {
    const paths = [...this.paths]
    return paths
      .filter(_ => _.startsWith(`${path}/`))
      .map(_ => _.slice(path.length + 1))
      .map(_ => _.split("/")[0])
  }

  async isDirectory(path: string) {
    const paths = [...this.paths]
    return paths.some(_ => _.startsWith(`${path}/`)) && !paths.includes(path)
  }
}

/**
 * Default Browser adapter.
 */
export const getBrowserAdapter = (list: FileList): IAdapter => ({
  fs: new FileSystem(list),
  subtle: crypto.subtle,
})
