import styled from "@emotion/styled"
import { useEffect, useMemo, useState } from "react"
import { ClickableContainer } from "../components/ItemFieldValue"
import { scrollbar } from "../styles"

const Container = styled.div`
  display: flex;
`
const ListContainer = styled.div`
  min-width: 150px;
  ul {
    list-style-type: none;
    margin-block-start: 0;
    padding-inline-start: 0;
  }
  li {
    line-height: 1.6em;
  }
`
const LicenseText = styled.div`
  flex-grow: 1;
  font-family: var(--monospace);
  max-height: 575px;
  overflow-y: scroll;
  white-space: pre-wrap;
`

export const LicenseView = () => {
  const [licenseInfo, setLicenseInfo] = useState<
    typeof import("../third-party-licenses.json")
  >(() => ({} as any))
  const names = useMemo(() => Object.keys(licenseInfo), [licenseInfo])

  const [selected, setSelected] = useState<string>()

  useEffect(() => {
    import("../third-party-licenses.json").then(json => setLicenseInfo(json.default))
  }, [])

  useEffect(() => {
    setSelected(names[0])
  }, [names])

  return (
    <Container>
      <ListContainer>
        <ul>
          {names.map(name => (
            <li
              key={name}
              style={name === selected ? { fontWeight: 600 } : undefined}
              onClick={() => setSelected(name)}
            >
              <ClickableContainer>{name}</ClickableContainer>
            </li>
          ))}
        </ul>
      </ListContainer>

      <LicenseText className={scrollbar}>
        {licenseInfo[selected as any]?.license}
      </LicenseText>
    </Container>
  )
}
