import styled from "@emotion/styled"
import { useEffect, useState } from "react"

export enum ToastType {
  Regular = "regular",
  Primary = "primary",
  Secondary = "secondary",
  Success = "success",
  Danger = "danger",
  Warning = "warning",
  Info = "info",
}

interface Message {
  message: string
  type: ToastType
}
interface InternalMessage extends Message {
  opacity: number
  id: number
}

export let toast: (message: Message) => void

const Container = styled.div``
const ToastContainer = styled.div`
  position: fixed;
  bottom: 0;
  right: 20px;
  padding: 8px 12px;
  border-radius: 5px;
  box-shadow: 0 0.5rem 1rem rgb(0 0 0 / 15%);
  transition: opacity 1s ease-in-out, bottom 0.3s linear;
`

let lastId = 0

export const Toast: React.FC = () => {
  const [list, setList] = useState<InternalMessage[]>([])

  useEffect(() => {
    toast = message => {
      const newId = ++lastId
      setList(list => list.concat({ ...message, id: newId, opacity: 1 }))
      setTimeout(() => {
        setList(list => list.map(x => (x.id === newId ? { ...x, opacity: 0 } : x)))
      }, 1000)
    }
  }, [])

  return (
    <Container>
      {list.map((message, i, { length }) => (
        <ToastContainer
          onTransitionEnd={e => {
            if (e.propertyName === "opacity") {
              setList(list => list.filter(x => x.id !== message.id))
            }
          }}
          key={message.id}
          style={{ opacity: message.opacity, bottom: 40 * (length - i) - 10 }}
          className={`color-${message.type}`}
        >
          {message.message}
        </ToastContainer>
      ))}
    </Container>
  )
}
