import styled from "@emotion/styled"
import { Modal } from "../components/Modal"
import { useLocaleContext, useTranslate } from "../i18n"
import { Key, useStorage } from "../utils/localStorage"

const FormItem = styled.div`
  display: flex;
  align-items: center;
  margin-bottom: 13px;
`
const FormLabel = styled.div`
  width: 120px;
`
const FormValue = styled.div`
  display: flex;
  align-items: center;
  flex-grow: 1;
  position: relative;
  min-width: 200px;
  select {
    width: 100%;
  }
`
const Checkbox = styled.input`
  margin-left: 0;
  margin-right: 8px;
`

const GhostLabel = styled.div`
  opacity: 0.5;
  position: absolute;
  left: 37px;
  pointer-events: none;
`

export const Settings: React.FC<{
  show: boolean
  onHide(): void
}> = ({ show, onHide }) => {
  const { locale, setLocale } = useLocaleContext()
  const t = useTranslate()

  const [enableAutoLock, setEnableAutoLock] = useStorage(Key.ENABLE_AUTO_LOCK)
  const [autolockAfter, setAutolockAfter] = useStorage(Key.AUTO_LOCK_AFTER)

  return (
    <Modal show={show} title={t.label.settings} onClose={onHide}>
      <FormItem>
        <FormLabel>{t.label.language}</FormLabel>
        <FormValue>
          <select
            title={t.label.language}
            value={locale}
            onChange={e => setLocale(e.currentTarget.value)}
          >
            <option value="en">English</option>
            <option value="fr">Français</option>
            <option value="ja">日本語</option>
          </select>
        </FormValue>
      </FormItem>

      <FormItem>
        <FormLabel title={t.tips.automatically_lock_after_inactivity}>
          {t.options.enable_autolock}
        </FormLabel>
        <FormValue>
          <Checkbox
            type="checkbox"
            checked={enableAutoLock}
            onChange={e => setEnableAutoLock(e.target.checked)}
          />
          <input
            type="number"
            value={autolockAfter}
            onChange={e => setAutolockAfter(e.target.valueAsNumber)}
            disabled={!enableAutoLock}
          />
          <GhostLabel>
            <span style={{ opacity: 0 }}>{autolockAfter} </span>
            {t.noun.seconds}
          </GhostLabel>
        </FormValue>
      </FormItem>
    </Modal>
  )
}
